==> 0.0.1.tar.gz: lib/widget/custom/custom_search_from_field.dart <==
import '../../common/values/colors.dart';
import '../../common/values/sizes.dart';
import '../../common/values/styles.dart';
import 'package:flutter/material.dart';

import 'custom_text_form_field.dart';

class CustomSearchFormField extends StatefulWidget {
  final String? labelText;
  final String hintText;
  final double? width;
  final double? height;
  final IconData? prefixIcon;
  final IconData? suffixIcon;
  final IconData? clearIcon;
  final TextEditingController controller;
  final FocusNode focusNode;
  final bool? isEnable;
  final Function(String)? onSubmit;
  final ValueChanged<String> onChange;
  final TextInputAction? textInputAction;
  final GestureTapCallback? onSuffixIconTap;
  final GestureTapCallback? onClearIconTap;
  final Color secondaryColor;
  final String? fontName;
  final Color? colorHintText;

  const CustomSearchFormField(
      {this.labelText,
      this.prefixIcon,
      this.suffixIcon,
      this.clearIcon,
      this.onSuffixIconTap,
      this.onSubmit,
      this.textInputAction,
      required this.hintText,
      required this.controller,
      required this.focusNode,
      required this.onChange,
      this.width,
      this.height,
      this.isEnable,
      this.onClearIconTap,
      required this.secondaryColor,
      this.fontName,
      this.colorHintText});

  @override
  State<CustomSearchFormField> createState() => _CustomSearchFormFieldState();
}

class _CustomSearchFormFieldState extends State<CustomSearchFormField> {
  bool? isShowClearIcon = false;

  @override
  Widget build(BuildContext context) {
    return Container(
      child: CustomTextFormField(
        isEnable: widget.isEnable,
        controller: widget.controller,
        focusNode: widget.focusNode,
        onChange: (value) {
          widget.onChange(value);
          if (value.isNotEmpty == true) {
            setState(() {
              isShowClearIcon = true;
            });
          }
        },
        textInputAction: widget.textInputAction ?? TextInputAction.done,
        width: widget.width,
        height: widget.height,
        textInputType: TextInputType.text,
        labelText: widget.labelText,
        hintText: widget.hintText,
        onSubmit: widget.onSubmit,
        hasClearIcon:
            widget.clearIcon != null && isShowClearIcon == true ? true : false,
        hasPrefixIcon: widget.prefixIcon != null ? true : false,
        hasSuffixIcon: widget.suffixIcon != null ? true : false,
        prefixIconCustom: checkPrefixIcon(),
        clearIcon: checkClearIcon(),
        suffixIcon: checksuffixIcon(),
        backgroundColor: AppColors.white,
        onSuffixIconTap: widget.onSuffixIconTap,
        onClearIconTap: () {
          setState(() {
            isShowClearIcon = false;
            widget.controller.clear();
            if (widget.onSubmit != null) {
              widget.onSubmit!(widget.controller.text);
            }
          });
        },
        isBoxShadow: true,
        hintTextStyle: Styles.customTextMediumStyle(
            fontName: widget.fontName, color: widget.colorHintText),
      ),
    );
  }

  Widget? checkPrefixIcon() {
    if (widget.prefixIcon != null) {
      return Icon(
        widget.prefixIcon,
        color: widget.secondaryColor,
      );
    } else {
      return null;
    }
  }

  Widget? checksuffixIcon() {
    return widget.suffixIcon != null
        ? Container(
            margin: EdgeInsets.only(right: Sizes.MARGIN_8),
            child: Icon(
              widget.suffixIcon,
              color: widget.secondaryColor,
              size: Sizes.ICON_SIZE_24,
            ),
          )
        : null;
  }

  Widget? checkClearIcon() {
    return widget.clearIcon != null
        ? Container(
            margin: EdgeInsets.only(right: Sizes.MARGIN_8),
            child: Icon(
              widget.clearIcon,
              color: AppColors.textColor2,
              size: Sizes.ICON_SIZE_24,
            ),
          )
        : null;
  }
}

==> 0.0.56.tar.gz: lib/widget/custom/custom_search_from_field.dart <==

import 'package:flutter/material.dart';

import '../../common/values/colors.dart';
import '../../common/values/sizes.dart';
import '../../common/values/styles.dart';
import 'custom_text_form_field.dart';

class CustomSearchFormField extends StatefulWidget {
  final String? labelText;
  final String hintText;
  final double? width;
  final double? height;
  final IconData? prefixIcon;
  final IconData? suffixIcon;
  final IconData? clearIcon;
  final TextEditingController controller;
  final FocusNode focusNode;
  final bool? isEnable;
  final Function(String)? onSubmit;
  final ValueChanged<String> onChange;
  final TextInputAction? textInputAction;
  final GestureTapCallback? onSuffixIconTap;
  final GestureTapCallback? onClearIconTap;

  const CustomSearchFormField(
      {this.labelText,
      this.prefixIcon,
      this.suffixIcon,
      this.clearIcon,
      this.onSuffixIconTap,
      this.onSubmit,
      this.textInputAction,
      required this.hintText,
      required this.controller,
      required this.focusNode,
      required this.onChange,
      this.width,
      this.height,
      this.isEnable,
      this.onClearIconTap});

  @override
  State<CustomSearchFormField> createState() => _CustomSearchFormFieldState();
}

class _CustomSearchFormFieldState extends State<CustomSearchFormField> {
  bool? isShowClearIcon = false;

  @override
  Widget build(BuildContext context) {
    return Container(
      child: CustomTextFormField(
        isEnable: widget.isEnable,
        controller: widget.controller,
        focusNode: widget.focusNode,
        onChange: (value) {
          widget.onChange(value);
          if (value.isNotEmpty == true) {
            setState(() {
              isShowClearIcon = true;
            });
          }
        },
        textInputAction: widget.textInputAction ?? TextInputAction.done,
        width: widget.width,
        height: widget.height,
        textInputType: TextInputType.text,
        labelText: widget.labelText,
        hintText: widget.hintText,
        onSubmit: widget.onSubmit,
        hasClearIcon:
            widget.clearIcon != null && isShowClearIcon == true ? true : false,
        hasPrefixIcon: widget.prefixIcon != null ? true : false,
        hasSuffixIcon: widget.suffixIcon != null ? true : false,
        prefixIconCustom: checkPrefixIcon(),
        clearIcon: checkClearIcon(),
        suffixIcon: checksuffixIcon(),
        backgroundColor: SharingColors.white,
        onSuffixIconTap: widget.onSuffixIconTap,
        onClearIconTap: () {
          setState(() {
            isShowClearIcon = false;
            widget.controller.clear();
            if (widget.onSubmit != null) {
              widget.onSubmit!(widget.controller.text);
            }
          });
        },
        isBoxShadow: true,
        hintTextStyle: Styles.customTextMediumStyle(),
      ),
    );
  }

  Widget? checkPrefixIcon() {
    if (widget.prefixIcon != null) {
      return Icon(
        widget.prefixIcon,
        color: SharingColors.secondaryColor,
      );
    } else {
      return null;
    }
  }

  Widget? checksuffixIcon() {
    return widget.suffixIcon != null
        ? Container(
            margin: EdgeInsets.only(right: Sizes.MARGIN_8),
            child: Icon(
              widget.suffixIcon,
              color: SharingColors.secondaryColor,
              size: Sizes.ICON_SIZE_24,
            ),
          )
        : null;
  }

  Widget? checkClearIcon() {
    return widget.clearIcon != null
        ? Container(
            margin: EdgeInsets.only(right: Sizes.MARGIN_8),
            child: Icon(
              widget.clearIcon,
              color: SharingColors.textColor2,
              size: Sizes.ICON_SIZE_24,
            ),
          )
        : null;
  }
}
